@@ -14,16 +14,17 @@ Date::Manip::Date_Init("TZ=GMT");
 
 # Example URL:
 #
-# http://finance.google.com/finance/historical?q=ibm&startdate=Jul+12%2C+2006&enddate=Jan+17%2C+2007&output=csv
+# http://www.google.com/finance/historical?q=IBM&startdate=Nov%2011%2C%202008&enddate=Feb%27%2C%202009&output=csv
 #
-# - this works too -
+# This also works:
 #
-# http://finance.google.com/finance/historical?q=ibm&startdate=07+12%2C+2006&enddate=01+17%2C+2007&output=csv
+# http://www.google.com/finance/historical?q=IBM&startdate=2008-11-11&enddate=2009-02-27&output=csv
 #
-# http://www.google.com/finance/historical?q=INDEXDJX:.DJI
+# weekly:
 #
-# Note: as of 08/2009, regular symbols had csv available, but some
-# such as DJI^ do not.
+# http://www.google.com/finance/historical?cid=99624&startdate=2008-11-11&enddate=2009-02-27&histperiod=weekly&output=csv
+#
+# Note: regular symbols have csv available, but some such as .DJI do not.
 
 sub new {
   my $that = shift;
@@ -35,11 +36,15 @@ sub new {
   $self;
 }
 
+sub url_base_csv { 'http://www.google.com/finance/historical' }
+
+sub granularities { qw( daily weekly ) }
 
 sub url_maker {
   my($self, %parms) = @_;
   my $target_mode = $parms{target_mode} || $self->target_mode;
   my $parse_mode  = $parms{parse_mode}  || $self->parse_mode;
+  my $grain       = $parms{granularity} || $self->granularity;
   # *always* block unknown target/mode cominations
   return undef unless $target_mode eq 'quote' && $parse_mode eq 'csv';
   my($ticker, $start_date, $end_date) =
@@ -47,21 +52,17 @@ sub url_maker {
   $start_date ||= $self->start_date;
   $end_date   ||= $self->end_date;
 
-  my $host = 'www.google.com';
-  my $cgi  = 'finance/historical';
-
   my($sy, $sm, $sd) = $self->ymd($start_date);
   my($ey, $em, $ed) = $self->ymd($end_date);
-  my $base_url = "http://$host/$cgi?";
   my @base_parms = (
     "q=$ticker",
-    "startdate=$sm+$sd%2C+$sy", "enddate=$em+$ed%2C+$ey",
-    "output=csv",
+    "startdate=$sy-$sm-$sd", "enddate=$ey-$em+$ed",
   );
-  my @urls =  ($base_url .  join('&', @base_parms));
+  push(@base_parms, 'histperiod=weekly') if $grain && $grain =~ /^w/i;
+  push(@base_parms, "output=csv");
+  my @urls = join('?', $self->url_base_csv, join('&', @base_parms));
 
   sub { pop @urls };
-
 }
 
 1;
@@ -134,7 +135,8 @@ guaranteed by the web sites themselves, and oftentimes is acquired
 elsewhere.
 
 Details for Googles's terms of use can be found here:
-I<http://www.google.com/accounts/TOS>
+
+  http://www.google.com/accounts/TOS?loc=us
 
 If you still have concerns, then use another site-specific historical
 quote instance, or none at all.
@@ -147,7 +149,7 @@ Matthew P. Sisk, E<lt>F<sisk@mojotoad.com>E<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007-2009 Matthew P. Sisk. All rights reserved. All wrongs
+Copyright (c) 2007-2010 Matthew P. Sisk. All rights reserved. All wrongs
 revenged. This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
